@@ -6,9 +6,8 @@ use Carp;
 use File::Spec::Functions qw/catfile catdir splitpath/;
 use Shipwright::Util;
 use File::Temp qw/tempdir/;
-use File::Copy qw/copy/;
-use File::Copy::Recursive qw/dircopy/;
-use File::Path;
+use File::Copy::Recursive qw/rcopy/;
+use File::Path qw/make_path remove_tree/;
 use List::MoreUtils qw/uniq firstidx/;
 use Module::Info;
 
@@ -61,13 +60,14 @@ sub initialize {
     my $dir =
       tempdir( 'shipwright_backend_base_XXXXXX', CLEANUP => 1, TMPDIR => 1 );
 
-    dircopy( Shipwright::Util->share_root, $dir )
+    rcopy( Shipwright::Util->share_root, $dir )
       or confess "copy share_root failed: $!";
 
     $self->_install_yaml_tiny($dir);
     $self->_install_clean_inc($dir);
     $self->_install_module_build($dir);
     $self->_install_file_compare($dir);
+    $self->_install_file_copy_recursive($dir);
 
     # set proper permissions for yml under /shipwright/
     my $sw_dir = catdir( $dir, 'shipwright' );
@@ -78,18 +78,8 @@ sub initialize {
     }
     closedir $sw_dh;
 
-    # share_root can't keep empty dirs, we have to create them manually
-    for (qw/scripts sources/) {
-        my $sub_dir = catdir( $dir, $_ );
-        mkdir $sub_dir;
-        open my $fh, '>', catfile( $sub_dir, '.exists' ) or confess $!;
-        close $fh;
-    }
     chmod 0644, catfile( $dir, 't', 'test' );
 
-    # hack for share_root living under blib/
-    unlink( catfile( $dir, '.exists' ) );
-
     return $dir;
 }
 
@@ -97,18 +87,17 @@ sub _install_module_build {
     my $self = shift;
     my $dir = shift;
     my $module_build_path = catdir( $dir, 'inc', 'Module', );
-    mkpath catdir( $module_build_path, 'Build' );
-    copy( Module::Info->new_from_module('Module::Build')->file,
+    make_path( catdir( $module_build_path, 'Build' ) );
+    rcopy( Module::Info->new_from_module('Module::Build')->file,
             $module_build_path ) or confess "copy Module/Build.pm failed: $!";
-    dircopy(
+    rcopy(
         catdir(
             Module::Info->new_from_module('Module::Build')->inc_dir, 'Module',
             'Build'
         ),
         catdir( $module_build_path, 'Build' )
       )
-      or confess "copy
-        Module/Build failed: $!";
+      or confess "copy Module/Build failed: $!";
 }
 
 sub _install_yaml_tiny {
@@ -116,8 +105,8 @@ sub _install_yaml_tiny {
     my $dir = shift;
 
     my $yaml_tiny_path = catdir( $dir, 'inc', 'YAML' );
-    mkpath $yaml_tiny_path;
-    copy( Module::Info->new_from_module('YAML::Tiny')->file, $yaml_tiny_path )
+    make_path( $yaml_tiny_path );
+    rcopy( Module::Info->new_from_module('YAML::Tiny')->file, $yaml_tiny_path )
       or confess "copy YAML/Tiny.pm failed: $!";
 }
 
@@ -125,9 +114,9 @@ sub _install_clean_inc {
     my $self = shift;
     my $dir = shift;
     my $util_inc_path = catdir( $dir, 'inc', 'Shipwright', 'Util' );
-    mkpath $util_inc_path;
+    make_path( $util_inc_path );
     for my $mod qw(Shipwright::Util::CleanINC Shipwright::Util::PatchModuleBuild) {
-        copy( Module::Info->new_from_module($mod)->file, $util_inc_path )
+        rcopy( Module::Info->new_from_module($mod)->file, $util_inc_path )
             or confess "copy $mod failed: $!";
     }
 }
@@ -137,11 +126,21 @@ sub _install_file_compare {
     my $dir = shift;
 
     my $path = catdir( $dir, 'inc', 'File' );
-    mkpath $path;
-    copy( Module::Info->new_from_module('File::Compare')->file, $path )
+    make_path( $path );
+    rcopy( Module::Info->new_from_module('File::Compare')->file, $path )
       or confess "copy File/Compare.pm failed: $!";
 }
 
+sub _install_file_copy_recursive {
+    my $self = shift;
+    my $dir = shift;
+
+    my $path = catdir( $dir, 'inc', 'File', 'Copy' );
+    make_path( $path );
+    rcopy( Module::Info->new_from_module('File::Copy::Recursive')->file, $path )
+      or confess "copy File/Copy/Recursive.pm failed: $!";
+}
+
 =item import
 
 import a dist.
