@@ -6,8 +6,8 @@ use Carp;
 use File::Spec::Functions qw/catfile/;
 use Shipwright::Util;
 use File::Temp qw/tempdir/;
-use File::Copy qw/copy/;
-use File::Copy::Recursive qw/dircopy/;
+use File::Copy::Recursive qw/rcopy/;
+use File::Path qw/remove_tree/;
 
 our %REQUIRE_OPTIONS = ( import => [qw/source/] );
 
@@ -126,10 +126,10 @@ sub _cmd {
                 my $tmp_dir =
                   tempdir( 'shipwright_backend_svk_XXXXXX', CLEANUP => 1, TMPDIR => 1 );
                 @cmd = (
-                    [ 'rm', '-rf', "$tmp_dir" ],
+                    sub { remove_tree( $tmp_dir ) },
                     [ $ENV{'SHIPWRIGHT_SVK'}, 'checkout', $self->repository . $path, $tmp_dir ],
-                    [ 'rm',  '-rf',      "$tmp_dir" ],
-                    [ 'cp', '-r', $source, "$tmp_dir" ],
+                    sub { remove_tree( $tmp_dir ) },
+                    sub { rcopy( $source, $tmp_dir ) },
                     [
                         $ENV{'SHIPWRIGHT_SVK'},      'commit',
                         '--import', $tmp_dir,
@@ -285,7 +285,7 @@ sub _update_file {
         target => $file,
     );
 
-    copy( $latest, $file ) or confess "can't copy $latest to $file: $!";
+    rcopy( $latest, $file ) or confess "can't copy $latest to $file: $!";
     $self->commit(
         path    => $file,
         comment => "updated $path",
@@ -307,7 +307,7 @@ sub _update_dir {
         target => $dir,
     );
 
-    dircopy( $latest, $dir ) or confess "can't copy $latest to $dir: $!";
+    rcopy( $latest, $dir ) or confess "can't copy $latest to $dir: $!";
     $self->commit(
         path    => $dir,
         comment => "updated $path",
